containertools.Cluster
======================

.. abjad-lineage:: abjad.tools.containertools.Cluster.Cluster.Cluster

.. autoclass:: abjad.tools.containertools.Cluster.Cluster.Cluster

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.containertools.Cluster.Cluster.Cluster.append
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.extend
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.index
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.insert
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.is_simultaneous
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.lilypond_format
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.override
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.pop
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.remove
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.reverse
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.select
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.select_leaves
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.select_notes_and_chords
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.set
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.storage_format
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__contains__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__copy__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__delitem__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__eq__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__getitem__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__len__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__mul__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__ne__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__repr__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__rmul__
      ~abjad.tools.containertools.Cluster.Cluster.Cluster.__setitem__

Bases
-----

- :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.override
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.set
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.is_simultaneous
   :noindex:

Methods
-------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.append
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.extend
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.index
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.insert
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.pop
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.remove
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.reverse
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.select
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.select_leaves
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__contains__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__copy__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__delitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__eq__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__getitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__len__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__mul__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__ne__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__repr__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__rmul__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__setitem__
   :noindex:
